@@ -15,8 +15,7 @@ logger = logging.getLogger(__name__)
 
 if t.TYPE_CHECKING:
     import pathlib
-
-    from typing_extensions import TypeAlias
+    from typing import TypeAlias
 
     from tmuxp.types import StrPath
 
@@ -194,7 +193,7 @@ def find_workspace_file(
             if not candidates:
                 file_error = (
                     "workspace-file not found "
-                    + f"in workspace dir (yaml/yml/json) {workspace_dir} for name"
+                    f"in workspace dir (yaml/yml/json) {workspace_dir} for name"
                 )
         else:
             candidates = [
@@ -218,9 +217,9 @@ def find_workspace_file(
                     "Use file names e.g. myproject.json, coolproject.yaml. "
                     "You can load them by filename.",
                 )
-            elif not len(candidates):
+            elif not candidates:
                 file_error = "No tmuxp files found in directory"
-        if len(candidates):
+        if candidates:
             workspace_file = candidates[0]
     elif not exists(workspace_file):
         file_error = "file not found"
