@@ -15,17 +15,44 @@ if t.TYPE_CHECKING:
     import pathlib
 
 
+class ConvertTestFixture(t.NamedTuple):
+    """Test fixture for tmuxp convert command tests."""
+
+    test_id: str
+    cli_args: list[str]
+
+
+CONVERT_TEST_FIXTURES: list[ConvertTestFixture] = [
+    ConvertTestFixture(
+        test_id="convert_current_dir",
+        cli_args=["convert", "."],
+    ),
+    ConvertTestFixture(
+        test_id="convert_yaml_file",
+        cli_args=["convert", ".tmuxp.yaml"],
+    ),
+    ConvertTestFixture(
+        test_id="convert_yaml_file_auto_confirm",
+        cli_args=["convert", ".tmuxp.yaml", "-y"],
+    ),
+    ConvertTestFixture(
+        test_id="convert_yml_file",
+        cli_args=["convert", ".tmuxp.yml"],
+    ),
+    ConvertTestFixture(
+        test_id="convert_yml_file_auto_confirm",
+        cli_args=["convert", ".tmuxp.yml", "-y"],
+    ),
+]
+
+
 @pytest.mark.parametrize(
-    "cli_args",
-    [
-        (["convert", "."]),
-        (["convert", ".tmuxp.yaml"]),
-        (["convert", ".tmuxp.yaml", "-y"]),
-        (["convert", ".tmuxp.yml"]),
-        (["convert", ".tmuxp.yml", "-y"]),
-    ],
+    list(ConvertTestFixture._fields),
+    CONVERT_TEST_FIXTURES,
+    ids=[test.test_id for test in CONVERT_TEST_FIXTURES],
 )
 def test_convert(
+    test_id: str,
     cli_args: list[str],
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
@@ -57,15 +84,36 @@ def test_convert(
     assert tmuxp_json.open().read() == json.dumps({"session_name": "hello"}, indent=2)
 
 
+class ConvertJsonTestFixture(t.NamedTuple):
+    """Test fixture for tmuxp convert json command tests."""
+
+    test_id: str
+    cli_args: list[str]
+
+
+CONVERT_JSON_TEST_FIXTURES: list[ConvertJsonTestFixture] = [
+    ConvertJsonTestFixture(
+        test_id="convert_json_current_dir",
+        cli_args=["convert", "."],
+    ),
+    ConvertJsonTestFixture(
+        test_id="convert_json_file",
+        cli_args=["convert", ".tmuxp.json"],
+    ),
+    ConvertJsonTestFixture(
+        test_id="convert_json_file_auto_confirm",
+        cli_args=["convert", ".tmuxp.json", "-y"],
+    ),
+]
+
+
 @pytest.mark.parametrize(
-    "cli_args",
-    [
-        (["convert", "."]),
-        (["convert", ".tmuxp.json"]),
-        (["convert", ".tmuxp.json", "-y"]),
-    ],
+    list(ConvertJsonTestFixture._fields),
+    CONVERT_JSON_TEST_FIXTURES,
+    ids=[test.test_id for test in CONVERT_JSON_TEST_FIXTURES],
 )
 def test_convert_json(
+    test_id: str,
     cli_args: list[str],
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
