@@ -186,10 +186,11 @@ windows:
 
 
 if t.TYPE_CHECKING:
-    from pytest_mock import MockerFixture
-    from typing_extensions import TypeAlias
+    from typing import TypeAlias
 
-    ExpectedOutput: TypeAlias = t.Optional[t.Union[str, list[str]]]
+    from pytest_mock import MockerFixture
+
+    ExpectedOutput: TypeAlias = str | list[str] | None
 
 
 class CLILoadFixture(t.NamedTuple):
@@ -309,7 +310,7 @@ def test_load(
     assert server.socket_name is not None
 
     monkeypatch.chdir(tmp_path)
-    for session_name, config_path in zip(session_names, config_paths):
+    for session_name, config_path in zip(session_names, config_paths, strict=False):
         tmuxp_config = pathlib.Path(
             config_path.format(tmp_path=tmp_path, TMUXP_CONFIGDIR=tmuxp_configdir),
         )
