@@ -10,7 +10,20 @@ bundled with tmuxp. Usage example:
 ...
 """
 
-from typing_extensions import NotRequired, TypedDict
+from __future__ import annotations
+
+import typing as t
+
+if t.TYPE_CHECKING:
+    from typing_extensions import NotRequired, TypedDict
+else:
+    # Fallback for runtime, though this module should not be imported at runtime
+    try:
+        from typing_extensions import NotRequired, TypedDict
+    except ImportError:
+        # Create dummy classes for runtime
+        NotRequired = t.Any  # type: ignore[misc, assignment]
+        TypedDict = type  # type: ignore[assignment, misc]
 
 
 class PluginTestConfigSchema(TypedDict):
